summaryrefslogtreecommitdiffhomepage
path: root/dev/ZBA
diff options
context:
space:
mode:
authorAmlal <amlal@el-mahrouss-logic.com>2024-09-12 03:16:15 +0200
committerAmlal <amlal@el-mahrouss-logic.com>2024-09-12 03:20:24 +0200
commitb323d403149db3d720a63af1087d44718821bd67 (patch)
treec15fdaf7053f40d8d6b89bc554e85998162391c7 /dev/ZBA
parent6d31d6e0959f224630317d247f489d18e65aa5bc (diff)
Kernel improvements, and Paging API changes.
ZKA: - Updated and fixed 4KB pages on ARM64. - Fixed 4KB pages on AMD64. - Refactor BMP allocator. ZBA: - Refactor Handover protocol. DDK: - Refactor and breaking API changes. HPFS: - Update code according to DDK. Signed-off-by: Amlal <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'dev/ZBA')
-rw-r--r--dev/ZBA/BootKit/BootKit.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/dev/ZBA/BootKit/BootKit.hxx b/dev/ZBA/BootKit/BootKit.hxx
index 0ddd6d30..590e50f4 100644
--- a/dev/ZBA/BootKit/BootKit.hxx
+++ b/dev/ZBA/BootKit/BootKit.hxx
@@ -185,7 +185,7 @@ static inline const UInt32 kRgbWhite = 0x00FFFFFF;
#define kBKBootFileMime "boot-x/file"
#define kBKBootDirMime "boot-x/dir"
/// @brief BootKit Disk Formatter.
template <typename BootDev>
class BDiskFormatFactory final
{
@@ -236,7 +236,7 @@ public:
return false;
}
- writer.Write(L"NEWOSLDR: Disk is ").Write(GIB(this->fDiskDev.GetDiskSize())).Write(L" GB.\r");
+ writer.Write(L"NEWOSLDR: Drive is ").Write(GIB(this->fDiskDev.GetDiskSize())).Write(L" GB.\r");
if (blockPart->DiskSize != this->fDiskDev.GetDiskSize() ||
blockPart->DiskSize < 1 ||
@@ -322,7 +322,7 @@ inline Boolean BDiskFormatFactory<BootDev>::Format(const Char* partName,
if (GIB(fDiskDev.GetDiskSize()) < cMinimumDiskSize)
{
- EFI::ThrowError(L"Disk-Too-Tiny", L"Can't format a New Filesystem partition here.");
+ EFI::ThrowError(L"Drive-Too-Tiny", L"Can't format a New Filesystem partition here.");
return false;
}
@@ -372,7 +372,7 @@ inline Boolean BDiskFormatFactory<BootDev>::Format(const Char* partName,
if (this->WriteRootCatalog(fileBlobs, blobCount, partBlock))
{
BTextWriter writer;
- writer.Write(L"NEWOSLDR: Disk formatted.\r");
+ writer.Write(L"NEWOSLDR: Drive formatted.\r");
return true;
}
@@ -185,7 +185,7 @@ static inline const UInt32 kRgbWhite = 0x00FFFFFF;
#define kBKBootFileMime "boot-x/file"
#define kBKBootDirMime "boot-x/dir"
-/// @brief BootKit Disk Formatter.
+/// @brief BootKit Drive Formatter.
template <typename BootDev>
class BDiskFormatFactory final